<template>
  <gree-view>
    <gree-page class="page-energyFlow">
      <gree-header :left-options="{ preventGoBack: true }" @on-click-back="goBack">{{ $language('btn.EnergyFlowCard') }}</gree-header>
      <div class="page-main" v-if="!isError">
        <gree-row>
          <gree-col
            v-for="(item, index) in ImgList"
            width="20"
            :id="`col-${item.key}`"
            class="item-col"
            :class="{
              'set-gray': item.gray
            }"
            :key="index"
          >
            <!-- 图标 -->
            <div class="icon">
              <img class="iconfont" :src="item.path" :id="`img-${item.key}`" />
            </div>
            <!-- 名称 -->
            <div class="item-group-text" v-text="item.name" />
          </gree-col>
        </gree-row>
      </div>
      <p class="refreshTime" v-text="`更新时间: ${refreshTime}`" v-if="!isError" />
      <div class="empty" v-else>
        <p class="emptyText">{{ '状态异常，请稍后重试' }}</p>
      </div>
      <!-- 刷新按钮 -->
      <gree-button class="btn-refresh" type="primary" @click="onClick" block round>状态刷新</gree-button>
    </gree-page>
  </gree-view>
</template>

<script>
import { Header, Toast, Row, Col, Button } from 'gree-ui';
import { mapState, mapMutations, mapActions, mapGetters } from 'vuex';
import { sendDataToGetEnergy } from '@PluginInterface';
import { types } from '@/store/types';
import dayjs from 'dayjs';

export default {
  components: {
    [Col.name]: Col,
    [Row.name]: Row,
    [Toast.name]: Toast,
    [Header.name]: Header,
    [Button.name]: Button
  },
  data() {
    return {
      refreshTime: ''
    };
  },
  computed: {
    ...mapState('control', {
      Pow: state => state.dataObject.Pow,
      mac: state => state.mac,
      EnergyFlow: state => state.dataObject.EnergyFlow || 0
    }),
    ...mapGetters('machine', ['identifierArr']),
    ImgList() {
      const result = [
        {
          key: '',
          path: require('@/assets/img/functionBtn/EnergyFlow/PV.png'),
          name: '光伏组件',
          gray: false
        },
        {
          key: 'arrow',
          path: [2, 3, 4, 5, 6, 7, 8, 9].includes(this.EnergyFlow)
            ? require('@/assets/img/functionBtn/EnergyFlow/arrow1.png')
            : require('@/assets/img/functionBtn/EnergyFlow/grayArrow.png'),
          name: '',
          gray: false
        },
        {
          key: '',
          path: this.Pow ? require('@/assets/img/functionBtn/EnergyFlow/ACon.png') : require('@/assets/img/functionBtn/EnergyFlow/ACoff.png'),
          name: '光伏空调',
          gray: false
        },
        {
          key: 'arrow',
          path: this.ImgPath(),
          name: '',
          gray: false
        },
        {
          key: '',
          path: require('@/assets/img/functionBtn/EnergyFlow/elcgrid.png'),
          name: '电网',
          gray: false
        },
        {
          key: 'line',
          path: this.savePath(),
          name: '',
          gray: false
        },
        {
          key: 'save',
          path: require('@/assets/img/functionBtn/EnergyFlow/saveenergy.png'),
          name: '储能',
          gray: [1, 3, 5, 7, 9, 11].includes(this.EnergyFlow) ? false : true
        }
      ];
      return result;
    },
    isError() {
      return this.EnergyFlow > 11 || this.EnergyFlow < 0;
    }
  },
  watch: {
    EnergyFlow: {
      handler(newVal, oldVal) {
        if (newVal !== oldVal) {
          this.getRefreshTime();
        }
      }
    }
  },
  mounted() {
    this.getRefreshTime();
  },
  methods: {
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapActions({
      sendCtrl: types.SEND_CTRL
    }),
    /**
     * @description 返回键
     */
    goBack() {
      this.$router.push({ name: 'Home' });
    },
    getRefreshTime() {
      this.refreshTime = dayjs().format('MM-DD HH:mm');
      return this.refreshTime;
    },
    onClick() {
      const { mac } = this;
      const sendMac = mac;
      const pmac = mac;
      const t = 'status';
      const cols = ['EnergyFlow'];
      const STATUS_JSON = JSON.stringify({ cols, mac, t, sub: mac });
      sendDataToGetEnergy(pmac, sendMac, STATUS_JSON)
        .then(_res => {
          console.log('能量流-------------------------', _res);
          const result = JSON.parse(_res)[0];
          this.setDataObject({ EnergyFlow: result });
        })
        .catch(e => {
          console.log('刷新失败', e);
        });
      this.getRefreshTime();
    },
    ImgPath() {
      if ([4, 5, 6, 7].includes(this.EnergyFlow)) {
        return require('@/assets/img/functionBtn/EnergyFlow/arrow1.png');
      } else if ([0, 1, 2, 3, 4].includes(this.EnergyFlow)) {
        return require('@/assets/img/functionBtn/EnergyFlow/grayArrow.png');
      } else if ([8, 9, 10, 11].includes(this.EnergyFlow)) {
        return require('@/assets/img/functionBtn/EnergyFlow/arrow2.png');
      } else {
        return require('@/assets/img/functionBtn/EnergyFlow/grayArrow.png');
      }
    },
    savePath() {
      if ([1, 3, 5, 7, 9, 11].includes(this.EnergyFlow)) {
        return require('@/assets/img/functionBtn/EnergyFlow/saveline.png');
      } else {
        return require('@/assets/img/functionBtn/EnergyFlow/dottedline.png');
      }
    }
  }
};
</script>

<style lang="scss">
.page-energyFlow {
  .gree-header {
    background-color: white;
    background-image: none;
  }
  .page-main {
    height: 600px;
    display: flex;
    background-color: white;
    justify-content: space-around;
    .row {
      width: 100%;
      text-align: center;
      align-items: center;
      padding-left: 80px;
      justify-content: flex-start;
      #img-arrow {
        height: 30px;
      }
      #img-line {
        height: 108px;
        width: 257px;
        right: 280px;
        top: 25%;
        position: absolute;
      }
      #col-save {
        right: 50px;
        top: 26%;
        position: absolute;
      }
      img {
        width: 160px;
        height: 150px;
      }
      .item-group-text {
        color: #404657;
        font-size: 30px;
      }
    }
  }
  .refreshTime {
    height: 80px;
    font-size: 36px;
    color: #989898;
    text-align: center;
    background-color: white;
  }
  .btn-refresh {
    width: 879px;
    height: 114px;
    left: 100px;
    bottom: 86px;
    font-size: 46px;
    color: #71acf1;
    line-height: 114px;
    position: absolute;
    border: 1px solid #71acf1;
    background-color: transparent;
  }
  .empty {
    width: 100%;
    height: 100%;
    position: absolute;
    background-size: 65%;
    background-color: #ffffff;
    background-repeat: no-repeat;
    background-position: 55% 30%;
    background-image: url('../../assets/img/nodata.png');
    .emptyText {
      opacity: 0.8;
      font-size: 46px;
      color: #404657;
      padding-top: 960px;
      text-align: center;
    }
  }
}
</style>
